@@ -7,3 +7,8 @@ pub use problem_0064 as problem_permutations;
 pub mod problem_0651;
 pub use problem_0651 as problem_651;
 pub use problem_0651 as problem_4_keys_keyboard;
+
+#[path = "0877-stone-game.rs"]
+pub mod problem_0877;
+pub use problem_0877 as problem_877;
+pub use problem_0877 as problem_stone_game;
